@@ -11,11 +11,11 @@ class ManufacturerEntity(RoleVisibility, SQLCamelModel, table=True):
 
     id: int = Field(
         primary_key=True,
-        sa_column=Column('id', Integer, Identity(start=0, cycle=True)),
-    )
-
-    name: str = Field(
-        sa_column=Column(TEXT)
+        sa_column=Column(
+            Integer,
+            Identity(start=1, cycle=True),
+            primary_key=True
+        ),
     )
 
     image_width: int | None
