@@ -13,17 +13,17 @@ class MotorcycleModelEntity(RoleVisibility, SQLCamelModel, table=True):
 
     id: int = Field(
         primary_key=True,
-        sa_column=Column(Integer, Identity(start=0, cycle=True)),
+        sa_column=Column(
+            Integer,
+            Identity(start=1, cycle=True),
+            primary_key=True
+        ),
     )
 
     manufacturer_id: int = Field(
         foreign_key='manufacturer.id',
     )
 
-    name: str = Field(
-        sa_column=Column(TEXT)
-    )
-
     technical_info: MotorcycleModel | None = Field(
         default=None,
         sa_column=Column(JSON),
